# remirepo/fedora spec file for php-mock-phpunit2
#
# Copyright (c) 2016-2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    c3cee2c13cd3e7ae78655ec828fdef409f78e292
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     php-mock
%global gh_project   php-mock-phpunit
%global with_tests   0%{!?_without_tests:1}
%global major        2

Name:           php-mock-phpunit%{major}
Version:        2.2.0
Release:        1%{?dist}
Summary:        Mock built-in PHP functions with PHPUnit.

License:        WTFPL
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

BuildArch:      noarch
BuildRequires:  php(language) >= 7
%if %{with_tests}
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(php-mock/php-mock-integration) >= 2   with php-composer(php-mock/php-mock-integration) < 3)
BuildRequires: (php-composer(php-mock/php-mock)             >= 2.1 with php-composer(php-mock/php-mock)             < 3)
# remirepo:3
%else
BuildRequires:  php-mock-integration2
%endif
BuildRequires:  phpunit6
%if 0%{?fedora} >= 28 || 0%{?rhel} >= 8
BuildRequires:  phpunit7
%endif
%if 0%{?fedora} >= 29 || 0%{?rhel} >= 8
BuildRequires:  phpunit8
%endif
# For autoloader
BuildRequires: php-composer(fedora/autoloader)
%endif

# from composer.json, "require": {
#        "php": ">=7",
#        "phpunit/phpunit": "^6 || ^7 || ^8",
#        "php-mock/php-mock-integration": "^2"
#    "conflict": {
#        "phpunit/phpunit-mock-objects": "3.2.0"
Requires:       php(language) >= 7
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (phpunit6 or phpunit7 or phpunit8)
Requires:      (php-composer(php-mock/php-mock-integration) >= 2   with php-composer(php-mock/php-mock-integration) < 3)
Requires:      (php-composer(php-mock/php-mock)             >= 2.1 with php-composer(php-mock/php-mock)             < 3)
# remirepo:4
%else
Requires:       phpunit6
Requires:       php-mock-integration2
%endif
# From phpcompatinfo report from version 2.1.0
# only Core

Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}


%description
Mock built-in PHP functions (e.g. time()) with PHPUnit.
This package relies on PHP's namespace fallback policy.
No further extension is needed.


%prep
%setup -q -n %{gh_project}-%{gh_commit}

: Create autoloader
cat << 'AUTOLOAD' | tee rpm.php
<?php
/* Autoloader for %{name} and its dependencies */
require_once '%{_datadir}/php/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('phpmock\\phpunit\\', __DIR__);
\Fedora\Autoloader\Dependencies::required(array(
    __DIR__ . '/compatibility.php',
    '%{_datadir}/php/phpmock2/autoload.php',
));
AUTOLOAD


%build
# Nothing


%install
mkdir -p             %{buildroot}%{_datadir}/php/
mkdir -p             %{buildroot}%{_datadir}/php/phpmock%{major}
cp -pr classes       %{buildroot}%{_datadir}/php/phpmock%{major}/phpunit
cp -pr compatibility %{buildroot}%{_datadir}/php/phpmock%{major}/phpunit/compatibility
cp -p  autoload.php  %{buildroot}%{_datadir}/php/phpmock%{major}/phpunit/compatibility.php
cp -p  rpm.php       %{buildroot}%{_datadir}/php/phpmock%{major}/phpunit/autoload.php


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{_datadir}/php/phpmock%{major}/phpunit/autoload.php';
require_once '%{_datadir}/tests/phpmock%{major}/autoload.php';
EOF

ret=0
: Run upstream test suite with phpunit6
for cmd in php php70 php71 php72 php73; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit6 --verbose || ret=1
  fi
done

if [ -x %{_bindir}/phpunit7 ]; then
: Run upstream test suite with phpunit7
for cmd in php php71 php72 php73; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit7 --verbose || ret=1
  fi
done
fi

if [ -x %{_bindir}/phpunit8 ]; then
: Run upstream test suite with phpunit8
for cmd in php php72 php73; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit8 --verbose || ret=1
  fi
done
fi
exit $ret
%else
: bootstrap build with test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc *.md
%{_datadir}/php/phpmock%{major}/phpunit


%changelog
* Wed Mar  6 2019 Remi Collet <remi@remirepo.net> - 2.2.0-1
- update to 2.2.0
- add dependency on php-mock2 for phpunit8 compatibility
- allow phpunit8

* Mon Oct  8 2018 Remi Collet <remi@remirepo.net> - 2.1.2-1
- update to 2.1.2

* Mon Apr  9 2018 Remi Collet <remi@remirepo.net> - 2.1.1-1
- update to 2.1.1

* Fri Mar 23 2018 Remi Collet <remi@remirepo.net> - 2.1.0-1
- update to 2.1.0
- add autoloader
- allow phpunit6 and phpunit7

* Tue Dec  5 2017 Remi Collet <remi@remirepo.net> - 2.0.1-1
- rename to php-mock-phpunit2
- Update to 2.0.1
- raise dependency on PHP 7
- raise dependency on php-mock-integration 2
- switch top phpunit6

* Thu May 11 2017 Remi Collet <remi@remirepo.net> - 1.1.2-3
- switch to fedora/autoloader

* Thu Jun 16 2016 Remi Collet <remi@fedoraproject.org> - 1.1.2-1
- update to 1.1.2 (no change)

* Mon Feb 22 2016 Remi Collet <remi@fedoraproject.org> - 1.1.1-2
- Fix: license is WTFPL

* Fri Feb 12 2016 Remi Collet <remi@fedoraproject.org> - 1.1.1-1
- initial package
